#! /usr/bin/env python3

import sys
import create_data

def parse_arguments():
    import argparse
    parser = argparse.ArgumentParser(
        description='computes accuracies for up (see paper)')
    parser.add_argument('-t', '--trainfile', required=True)
    parser.add_argument('-e', '--evalfile', required=True)
    parser.add_argument('-f', '--feature', required=True,
                        choices=create_data.feature_map.keys())
    return parser.parse_args()


def train_model(trainfile, ffunc):
    """trains a simple model from trainfile
       with ffunc as the feature extraction function"""
    model = {}
    sentence = []
    sys.stderr.write("Training...\n")
    num_lines = 0
    for line in trainfile:
        if (num_lines % 10000 == 0):
            sys.stderr.write("processed %d lines\n" %(num_lines,))
        num_lines += 1

        line = line.strip()
        if line != "":
            sentence.append(line.split("\t"))
            continue
        # if sentence is complete, process it
        for splitted in sentence:
            word = splitted[1]
            try:
                label = ffunc(splitted, sentence)
            except:
                # no label found
                continue
            if not word in model:
                model[word] = {}
            if not label in model[word]:
                model[word][label] = 1
            else:
                model[word][label] += 1
        # empty sentence
        sentence = []
    strippedmodel = {}
    for word, dist in model.items():
        bestlabel = ""
        bestnum = 0
        for label, num in dist.items():
            if num > bestnum:
                bestlabel = label
                bestnum = num
        strippedmodel[word] = bestlabel
    return strippedmodel


def evaluate(evalfile, ffunc, model):
    sys.stderr.write("Evaluating...\n")
    num_lines = 0
    sentence = []
    num = 0
    numcorrect = 0
    for line in evalfile:
        if (num_lines % 10000 == 0):
            sys.stderr.write("processed %d lines\n" %(num_lines,))
        num_lines += 1

        line = line.strip()
        if line != "":
            sentence.append(line.split("\t"))
            continue
        # if sentence is complete, process it
        for splitted in sentence:
            word = splitted[1]
            try:
                label = ffunc(splitted, sentence)
                plabel = model[word]
                numcorrect += label == plabel
                num += 1
            except:
                pass #ignore unseen words and non-existing labels
        # empty the sentence
        sentence = []
    return numcorrect*100.0/num


def main():
    args = parse_arguments()
    ffunc = create_data.get_feature_func(args.trainfile, args.feature)
    trainfile = open(args.trainfile)
    evalfile = open(args.evalfile)

    model = train_model(trainfile, ffunc)
    print(str(evaluate(evalfile, ffunc, model)))

if __name__ == "__main__":
    main()

