#!/bin/bash

set -e

datapath=$1
language=$2
VECTOR_SIZE=$3
WINDOW_SIZE=$4

# ---------------------------------------- #
# Things that might be configured later on #
# ---------------------------------------- #
VOCAB_MIN_COUNT=5
MAX_ITER=15
NUM_THREADS=24
X_MAX=10
VERBOSE=2

mkdir -p ${datapath}/glove-temp

# ---------------------------------------- #
# Variable depending only on previous ones #
# ---------------------------------------- #
CORPUS=${datapath}/cleaned/${language}.txt
VOCAB_FILE=${datapath}/glove-temp/vocab-${language}.txt
COOCCURRENCE_FILE=${datapath}/glove-temp/cooc-${language}-${WINDOW_SIZE}.bin
COOCCURRENCE_SHUF_FILE=${datapath}/glove-temp/cooc-${language}-${WINDOW_SIZE}.shuf.bin

SAVE_FILE=${datapath}/embeddings/${language}-glove-${VECTOR_SIZE}-${WINDOW_SIZE}

MEMORY=8.0

cd glove

if [ ! -e $VOCAB_FILE ]; then
	./vocab_count -verbose $VERBOSE < $CORPUS > $VOCAB_FILE
fi

if [ ! -e $COOCCURRENCE_FILE ]; then
	./cooccur -vocab-file $VOCAB_FILE -verbose $VERBOSE -window-size $WINDOW_SIZE < $CORPUS > $COOCCURRENCE_FILE
fi

if [ ! -e $COOCCURRENCE_SHUF_FILE ]; then
	./shuffle -memory $MEMORY -verbose $VERBOSE < $COOCCURRENCE_FILE > $COOCCURRENCE_SHUF_FILE
fi

if [ ! -e $SAVE_FILE ]; then
	echo ./glove -save-file $SAVE_FILE -threads $NUM_THREADS -input-file $COOCCURRENCE_SHUF_FILE -x-max $X_MAX -iter $MAX_ITER -vector-size $VECTOR_SIZE -binary 0 -vocab-file $VOCAB_FILE -verbose $VERBOSE
	./glove -save-file $SAVE_FILE -threads $NUM_THREADS -input-file $COOCCURRENCE_SHUF_FILE -x-max $X_MAX -iter $MAX_ITER -vector-size $VECTOR_SIZE -binary 0 -vocab-file $VOCAB_FILE -verbose $VERBOSE
fi
