#!/bin/bash

set -e

DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
cd $DIR

datapath=$1
language=$2
VECTOR_SIZE=$3
WINDOW_SIZE=$4
# TYPE=$5

# ---------------------------------------- #
# Things that might be configured later on #
# ---------------------------------------- #
VOCAB_MIN_COUNT=5
MAX_ITER=15
NUM_THREADS=8
X_MAX=10
VERBOSE=2

mkdir -p ${datapath}/w2f-temp

# ---------------------------------------- #
# Variable depending only on previous ones #
# ---------------------------------------- #
CORPUS=~/data/unlabeled/Unlabeled.${language}.pred.conll

SAVE_FILE=${datapath}/embeddings/${language}-w2vf-${VECTOR_SIZE}-${WINDOW_SIZE}.txt

COUNTED_VOCAB=${datapath}/w2f-temp/${language}-counted.txt
DEP_CONTEXT=${datapath}/w2f-temp/${language}-dep.contexts


CV=${datapath}/w2f-temp/${language}-cv.txt
WV=${datapath}/w2f-temp/${language}-wv.txt

cut -f 2 $CORPUS | python scripts/vocab.py 50 > $COUNTED_VOCAB
cat $CORPUS | python scripts/extract_deps.py  $COUNTED_VOCAB 100 > $DEP_CONTEXT


# 2. Create word and context vocabularies:

./count_and_filter -train $DEP_CONTEXT -cvocab $CV -wvocab $WV -min-count 100

         
./word2vecf -train $DEP_CONTEXT -wvocab $WV -cvocab $CV -output $SAVE_FILE -size $VECTOR_SIZE -cbow 0 -threads 24 -debug 1
